@@ -623,8 +623,7 @@ class BayesModelBuilder:
             src_dict[dest].append(src)
 
         node_list = list(set(node_list))
-        print('node_list',node_list)
-
+        
         for node in node_list:
             self.add_variable("g_{}".format(node), "normal", 0, 1)  # gain
             self.add_variable("b_{}".format(node), "normal", 0, 1)  # gain
@@ -638,7 +637,6 @@ class BayesModelBuilder:
             else:
                 self.add_variable("{}[0]".format(node), "normal", 0, 1)
 
-        print('src_dict', src_dict)
         for dest in src_dict.keys():
             src_list = src_dict[dest]
             for src in src_list:
